#[non_exhaustive]
pub enum Event { Name { name: String, }, Description { description: String, }, ConnectorId { connector_id: u32, }, Done, Withdrawn, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Name

name

The compositor sends this event once the connector is created to indicate the name of this connector. This will not change for the duration of the Wayland session, but is not guaranteed to be consistent between sessions.

If the compositor supports wl_output version 4 and this connector corresponds to a wl_output, the compositor should use the same name as for the wl_output.

Fields

name: String

connector name



Description

description

The compositor sends this event once the connector is created to provide a human-readable description for this connector, which may be presented to the user. The compositor may send this event multiple times over the lifetime of this object to reflect changes in the description.

Fields

description: String

connector description



ConnectorId

connector_id

The compositor sends this event once the connector is created to indicate the DRM object ID which represents the underlying connector that is being offered. Note that the final lease may include additional object IDs, such as CRTCs and planes.

Fields

connector_id: u32

DRM connector ID



Done

all properties have been sent

This event is sent after all properties of a connector have been sent. This allows changes to the properties to be seen as atomic even if they happen via multiple events.



Withdrawn

lease offer withdrawn

Sent to indicate that the compositor will no longer honor requests for DRM leases which include this connector. The client may still issue a lease request including this connector, but the compositor will send wp_drm_lease_v1.finished without issuing a lease fd. Compositors are encouraged to send this event when they lose access to connector, for example when the connector is hot-unplugged, when the connector gets leased to a client or when the compositor loses DRM master.

If a client holds a lease for the connector, the status of the lease remains the same. The client should destroy the object after receiving this event.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message