Struct WpDrmLeaseConnectorV1
pub struct WpDrmLeaseConnectorV1 { /* private fields */ }wayland and Linux only.Expand description
a leasable DRM connector
Represents a DRM connector which is available for lease. These objects are created via wp_drm_lease_device_v1.connector events, and should be passed to lease requests via wp_drm_lease_request_v1.request_connector. Immediately after the wp_drm_lease_connector_v1 object is created the compositor will send a name, a description, a connector_id and a done event. When the description is updated the compositor will send a description event followed by a done event.
See also the Event enum for this interface.
Implementations
impl WpDrmLeaseConnectorV1
impl WpDrmLeaseConnectorV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy connector
The client may send this request to indicate that it will not use this connector. Clients are encouraged to send this after receiving the “withdrawn” event so that the server can release the resources associated with this connector offer. Neither existing lease requests nor leases will be affected.